==> kvpnc_0.8.orig.tar.gz: kvpnc-0.8/src/importcertificatedialog.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef IMPORTCERTIFICATEDIALOG_H
#define IMPORTCERTIFICATEDIALOG_H

#include "importcertificatedialogbase.h"
#include <qprocess.h>
#include <qstring.h>
#include <kdialogbase.h>
#include "kvpncconfig.h"

/**
@author Christoph Thielecke
*/
class ImportCertificateDialog : public KDialogBase {
		Q_OBJECT
	public:
		ImportCertificateDialog(QWidget *parent, const QString& caption, KVpncConfig *GlobalConfig);

		~ImportCertificateDialog();
		void canAccept();
		QString filename;
		QString certpath;
		QString importpassword;
		QString privatekeypassword;
		QString privatekeyagainpassword;
		QString pathToOpenSSL;
		QString certHash;
		QString certName;
		bool importOk;
		bool doHash;
		bool importSuccess;
		QProcess *ImportProcess;
		
protected:
		enum ImportType {pkcs12_freeswan=0,pkcs12_racoon=1,ca_der=2};
		KVpncConfig *GlobalConfig;
		bool done;


	public slots:
		void accept();
		void exit();
	
	private slots:
		void readFromStdout_import();
		void readFromStderr_import();
		void doLink();
		void doCacert();
		void doPrivateKey();
		void doCreateHash();
		void typeToggeled(int type);

	public:
		ImportCertificateDialogBase *main;
};

#endif

==> kvpnc_0.8.2.1.orig.tar.gz: kvpnc-0.8.2.1.orig/src/importcertificatedialog.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef IMPORTCERTIFICATEDIALOG_H
#define IMPORTCERTIFICATEDIALOG_H

#include "importcertificatedialogbase.h"
#include <qprocess.h>
#include <qstring.h>
#include <kdialogbase.h>
#include "kvpncconfig.h"

/**
@author Christoph Thielecke
*/
class ImportCertificateDialog : public KDialogBase {
		Q_OBJECT
	public:
		ImportCertificateDialog(QWidget *parent, const char* caption, KVpncConfig *GlobalConfig);

		~ImportCertificateDialog();
		void canAccept();
		QString filename;
		QString certpath;
		QString importpassword;
		QString privatekeypassword;
		QString privatekeyagainpassword;
		QString pathToOpenSSL;
		QString certHash;
		QString certName;
		bool importOk;
		bool doHash;
		bool importSuccess;
		QProcess *ImportProcess;
		
protected:
		enum ImportType {pkcs12_freeswan=0,pkcs12_racoon=1,ca_der=2};
		KVpncConfig *GlobalConfig;
		bool done;


	public slots:
		void accept();
		void exit();
	
	private slots:
		void readFromStdout_import();
		void readFromStderr_import();
		void doLink();
		void doCacert();
		void doPrivateKey();
		void doCreateHash();
		void typeToggeled(int type);

	public:
		ImportCertificateDialogBase *main;
};

#endif
